==> flyway-core-11.9.2-sources.jar: org/flywaydb/core/internal/exception/sqlExceptions/FlywaySqlUnableToConnectToDbException.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2025 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.internal.exception.sqlExceptions;

import java.sql.SQLException;
import javax.sql.DataSource;
import org.flywaydb.core.internal.exception.FlywaySqlException;

@SuppressWarnings("ClassTooDeepInInheritanceTree")
public class FlywaySqlUnableToConnectToDbException extends FlywaySqlException {
    public FlywaySqlUnableToConnectToDbException(final SQLException sqlException, final DataSource dataSource) {
        super("Unable to obtain connection from database"
            + getDataSourceInfo(dataSource, false)
            + ": "
            + sqlException.getMessage(), sqlException);
    }
}

==> flyway-core-11.17.1-sources.jar: org/flywaydb/core/internal/exception/sqlExceptions/FlywaySqlUnableToConnectToDbException.java <==
/*-
 * ========================LICENSE_START=================================
 * flyway-core
 * ========================================================================
 * Copyright (C) 2010 - 2025 Red Gate Software Ltd
 * ========================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */
package org.flywaydb.core.internal.exception.sqlExceptions;

import java.sql.SQLException;
import javax.sql.DataSource;
import org.flywaydb.core.internal.exception.FlywaySqlException;

@SuppressWarnings("ClassTooDeepInInheritanceTree")
public class FlywaySqlUnableToConnectToDbException extends FlywaySqlException {
    public FlywaySqlUnableToConnectToDbException(final SQLException sqlException, final DataSource dataSource) {
        super("Unable to obtain connection from database"
            + getDataSourceInfo(dataSource, false)
            + ": "
            + sqlException.getMessage(), sqlException, FlywaySqlServerErrorCode.CONNECTION_FAILURE);
    }
}
